@@ -230,6 +230,8 @@ class Resource(object):
         DEPLOYED = "Deployed"
         PENDING = "Pending"
         COMPLETED = "Completed"
+        RUNNING = "Running"
+        TERMINATING = "Terminating"
 
     class Condition:
         UPGRADEABLE = "Upgradeable"
