@@ -26,6 +26,14 @@ class VirtualMachine(NamespacedResource):
         ALWAYS = "Always"
         RERUNONFAILURE = "RerunOnFailure"
 
+    class Status(NamespacedResource.Status):
+        MIGRATING = "Migrating"
+        PAUSED = "Paused"
+        PROVISIONING = "Provisioning"
+        STARTING = "Starting"
+        STOPPED = "stopped"
+        STOPPING = "Stopping"
+
     def __init__(
         self,
         name=None,
